agentle.mcp.models.call\_tool\_result
=====================================

.. automodule:: agentle.mcp.models.call_tool_result

   
   .. rubric:: Functions

   .. autosummary::
   
      Field
   
   .. rubric:: Classes

   .. autosummary::
   
      BaseModel
      CallToolResult
      EmbeddedResource
      ImageContent
      Sequence
      TextContent
   